@@ -21,6 +21,9 @@ Schema:
       "ip":                       string,
       "ip_compressed":            string,
       "ip_exploded":              string,
+      "ip_split": [
+                                  string
+      ],
       "scope_id":                 string/null,
       "ipv4_mapped":              string/null,
       "six_to_four":              string/null,
@@ -78,6 +81,12 @@ Examples:
       "ip": "192.168.2.10",
       "ip_compressed": "192.168.2.10",
       "ip_exploded": "192.168.2.10",
+      "ip_split": [
+        "192",
+        "168",
+        "2",
+        "10"
+      ],
       "scope_id": null,
       "ipv4_mapped": null,
       "six_to_four": null,
@@ -133,6 +142,12 @@ Examples:
       "ip": "192.168.2.10",
       "ip_compressed": "192.168.2.10",
       "ip_exploded": "192.168.2.10",
+      "ip_split": [
+        "192",
+        "168",
+        "2",
+        "10"
+      ],
       "scope_id": null,
       "ipv4_mapped": null,
       "six_to_four": null,
@@ -186,14 +201,24 @@ Examples:
       "version": 6,
       "max_prefix_length": 128,
       "ip": "127:0:de::1",
-      "ip_compressed": "127:0:de::1%128",
+      "ip_compressed": "127:0:de::1",
       "ip_exploded": "0127:0000:00de:0000:0000:0000:0000:0001",
+      "ip_split": [
+        "0127",
+        "0000",
+        "00de",
+        "0000",
+        "0000",
+        "0000",
+        "0000",
+        "0001"
+      ],
       "scope_id": "128",
       "ipv4_mapped": null,
       "six_to_four": null,
       "teredo_client": null,
       "teredo_server": null,
-      "dns_ptr": "1.0.0.0.0.0.0.0.0.0.0.0.0.0.0.0.....0.7.2.1.0.ip6.arpa",
+      "dns_ptr": "1.0.0.0.0.0...0.0.0.e.d.0.0.0.0.0.0.7.2.1.0.ip6.arpa",
       "network": "127:0:de::",
       "broadcast": "127:0:de::ffff:ffff",
       "hostmask": "::ffff:ffff",
@@ -226,13 +251,13 @@ Examples:
         "last_host": "01:27:00:00:00:de:00:00:00:00:00:00:ff:ff:ff:fe"
       },
       "bin": {
-        "ip": "000000010010011100000000000000000000000011011110000000...",
-        "network": "0000000100100111000000000000000000000000110111100...",
-        "broadcast": "00000001001001110000000000000000000000001101111...",
-        "hostmask": "000000000000000000000000000000000000000000000000...",
-        "netmask": "1111111111111111111111111111111111111111111111111...",
-        "first_host": "0000000100100111000000000000000000000000110111...",
-        "last_host": "00000001001001110000000000000000000000001101111..."
+        "ip": "0000000100100111000000000000000000000000110...000000000001",
+        "network": "00000001001001110000000000000000000000...000000000000",
+        "broadcast": "000000010010011100000000000000000000...111111111111",
+        "hostmask": "0000000000000000000000000000000000000...111111111111",
+        "netmask": "11111111111111111111111111111111111111...000000000000",
+        "first_host": "00000001001001110000000000000000000...000000000001",
+        "last_host": "000000010010011100000000000000000000...1111111111110"
       }
     }
 
@@ -243,12 +268,22 @@ Examples:
       "ip": "127:0:de::1",
       "ip_compressed": "127:0:de::1",
       "ip_exploded": "0127:0000:00de:0000:0000:0000:0000:0001",
+      "ip_split": [
+        "0127",
+        "0000",
+        "00de",
+        "0000",
+        "0000",
+        "0000",
+        "0000",
+        "0001"
+      ],
       "scope_id": null,
       "ipv4_mapped": null,
       "six_to_four": null,
       "teredo_client": null,
       "teredo_server": null,
-      "dns_ptr": "1.0.0.0.0.0.0....0.0.0.e.d.0.0.0.0.0.0.7.2.1.0.ip6.arpa",
+      "dns_ptr": "1.0.0.0.0.0....0.0.0.0.e.d.0.0.0.0.0.0.7.2.1.0.ip6.arpa",
       "network": "127:0:de::1",
       "broadcast": "127:0:de::1",
       "hostmask": "::",
@@ -281,13 +316,13 @@ Examples:
         "last_host": "01:27:00:00:00:de:00:00:00:00:00:00:00:00:00:01"
       },
       "bin": {
-        "ip": "0000000100100111000000000000000000000000110111100000000...",
-        "network": "00000001001001110000000000000000000000001101111000...",
-        "broadcast": "000000010010011100000000000000000000000011011110...",
-        "hostmask": "0000000000000000000000000000000000000000000000000...",
-        "netmask": "11111111111111111111111111111111111111111111111111...",
-        "first_host": "00000001001001110000000000000000000000001101111...",
-        "last_host": "000000010010011100000000000000000000000011011110..."
+        "ip": "0000000100100111000000000000000000000000110111100...000001",
+        "network": "00000001001001110000000000000000000000001101...000001",
+        "broadcast": "000000010010011100000000000000000000000011...000001",
+        "hostmask": "0000000000000000000000000000000000000000000...000000",
+        "netmask": "11111111111111111111111111111111111111111111...111111",
+        "first_host": "00000001001001110000000000000000000000001...000001",
+        "last_host": "000000010010011100000000000000000000000011...0000001"
       }
     }
 
@@ -299,12 +334,22 @@ Examples:
       "ip": "::ffff:c0a8:123",
       "ip_compressed": "::ffff:c0a8:123",
       "ip_exploded": "0000:0000:0000:0000:0000:ffff:c0a8:0123",
+      "ip_split": [
+        "0000",
+        "0000",
+        "0000",
+        "0000",
+        "0000",
+        "ffff",
+        "c0a8",
+        "0123"
+      ],
       "scope_id": null,
       "ipv4_mapped": "192.168.1.35",
       "six_to_four": null,
       "teredo_client": null,
       "teredo_server": null,
-      "dns_ptr": "3.2.1.0.8.a.0.c.f.f.f.f.0.0.0....0.0.0.0.0.0.0.ip6.arpa",
+      "dns_ptr": "3.2.1.0.8.a.0.c.f.f.f.f.0.0....0.0.0.0.0.0.ip6.arpa",
       "network": "::ffff:c0a8:123",
       "broadcast": "::ffff:c0a8:123",
       "hostmask": "::",
@@ -337,13 +382,13 @@ Examples:
         "last_host": "00:00:00:00:00:00:00:00:00:00:ff:ff:c0:a8:01:23"
       },
       "bin": {
-        "ip": "0000000000000000000000000000000000000000000000000000000...",
-        "network": "00000000000000000000000000000000000000000000000000...",
-        "broadcast": "000000000000000000000000000000000000000000000000...",
-        "hostmask": "0000000000000000000000000000000000000000000000000...",
-        "netmask": "11111111111111111111111111111111111111111111111111...",
-        "first_host": "00000000000000000000000000000000000000000000000...",
-        "last_host": "000000000000000000000000000000000000000000000000..."
+        "ip": "000000000000000000000000000000000000000000000...100100011",
+        "network": "0000000000000000000000000000000000000000...000100011",
+        "broadcast": "00000000000000000000000000000000000000...000100011",
+        "hostmask": "000000000000000000000000000000000000000...000000000",
+        "netmask": "1111111111111111111111111111111111111111...111111111",
+        "first_host": "0000000000000000000000000000000000000...100100011",
+        "last_host": "00000000000000000000000000000000000000...0100100011"
       }
     }
 
@@ -355,12 +400,22 @@ Examples:
       "ip": "2002:c000:204::",
       "ip_compressed": "2002:c000:204::",
       "ip_exploded": "2002:c000:0204:0000:0000:0000:0000:0000",
+      "ip_split": [
+        "2002",
+        "c000",
+        "0204",
+        "0000",
+        "0000",
+        "0000",
+        "0000",
+        "0000"
+      ],
       "scope_id": null,
       "ipv4_mapped": null,
       "six_to_four": "192.0.2.4",
       "teredo_client": null,
       "teredo_server": null,
-      "dns_ptr": "0.0.0.0.0.0.0.0......0.4.0.2.0.0.0.0.c.2.0.0.2.ip6.arpa",
+      "dns_ptr": "0.0.0.0.0.0.0...0.0.0.4.0.2.0.0.0.0.c.2.0.0.2.ip6.arpa",
       "network": "2002:c000:204::",
       "broadcast": "2002:c000:204:ffff:ffff:ffff:ffff:ffff",
       "hostmask": "::ffff:ffff:ffff:ffff:ffff",
@@ -393,13 +448,13 @@ Examples:
         "last_host": "20:02:c0:00:02:04:ff:ff:ff:ff:ff:ff:ff:ff:ff:fe"
       },
       "bin": {
-        "ip": "0010000000000010110000000000000000000010000001000000000...",
-        "network": "00100000000000101100000000000000000000100000010000...",
-        "broadcast": "001000000000001011000000000000000000001000000100...",
-        "hostmask": "0000000000000000000000000000000000000000000000001...",
-        "netmask": "11111111111111111111111111111111111111111111111100...",
-        "first_host": "00100000000000101100000000000000000000100000010...",
-        "last_host": "001000000000001011000000000000000000001000000100..."
+        "ip": "00100000000000101100000000000000000000100000010...00000000",
+        "network": "001000000000001011000000000000000000001000...00000000",
+        "broadcast": "0010000000000010110000000000000000000010...11111111",
+        "hostmask": "00000000000000000000000000000000000000000...11111111",
+        "netmask": "111111111111111111111111111111111111111111...00000000",
+        "first_host": "001000000000001011000000000000000000001...00000001",
+        "last_host": "0010000000000010110000000000000000000010...111111110"
       }
     }
 
@@ -411,12 +466,22 @@ Examples:
       "ip": "2001:0:4136:e378:8000:63bf:3fff:fdd2",
       "ip_compressed": "2001:0:4136:e378:8000:63bf:3fff:fdd2",
       "ip_exploded": "2001:0000:4136:e378:8000:63bf:3fff:fdd2",
+      "ip_split": [
+        "2001",
+        "0000",
+        "4136",
+        "e378",
+        "8000",
+        "63bf",
+        "3fff",
+        "fdd2"
+      ],
       "scope_id": null,
       "ipv4_mapped": null,
       "six_to_four": null,
       "teredo_client": "192.0.2.45",
       "teredo_server": "65.54.227.120",
-      "dns_ptr": "2.d.d.f.f.f.f.3.f.b.3.6.0.0.0....0.0.0.1.0.0.2.ip6.arpa",
+      "dns_ptr": "2.d.d.f.f.f.f.3.f.b.3.6.0.0.0.8.8....0.1.0.0.2.ip6.arpa",
       "network": "2001:0:4136:e378:8000:63bf:3fff:fdd2",
       "broadcast": "2001:0:4136:e378:8000:63bf:3fff:fdd2",
       "hostmask": "::",
@@ -449,13 +514,13 @@ Examples:
         "last_host": "20:01:00:00:41:36:e3:78:80:00:63:bf:3f:ff:fd:d2"
       },
       "bin": {
-        "ip": "001000000000000100000000000000000100000100110110111000...",
-        "network": "0010000000000001000000000000000001000001001101101...",
-        "broadcast": "00100000000000010000000000000000010000010011011...",
-        "hostmask": "000000000000000000000000000000000000000000000000...",
-        "netmask": "1111111111111111111111111111111111111111111111111...",
-        "first_host": "0010000000000001000000000000000001000001001101...",
-        "last_host": "00100000000000010000000000000000010000010011011..."
+        "ip": "0010000000000001000000000000000001000001001...110111010010",
+        "network": "00100000000000010000000000000000010000...110111010010",
+        "broadcast": "001000000000000100000000000000000100...110111010010",
+        "hostmask": "0000000000000000000000000000000000000...000000000000",
+        "netmask": "11111111111111111111111111111111111111...111111111111",
+        "first_host": "00100000000000010000000000000000010...110111010010",
+        "last_host": "001000000000000100000000000000000100...110111010010"
       }
     }
 """
@@ -468,7 +533,7 @@ import jc.utils
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.1'
+    version = '1.3'
     description = 'IPv4 and IPv6 Address string parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -495,7 +560,7 @@ def _process(proc_data: Dict) -> Dict:
 
 def _b2a(byte_string: bytes) -> str:
     """Convert a byte string to a colon-delimited hex ascii string"""
-    # need try/except since seperator was only introduced in python 3.8.
+    # need try/except since separator was only introduced in python 3.8.
     # provides compatibility for python 3.6 and 3.7.
     try:
       return binascii.hexlify(byte_string, ':').decode('utf-8')
@@ -569,7 +634,10 @@ def parse(
         try:
             hostmask_string = str(interface.hostmask)
         except AttributeError:
-            hostmask_string = '0.0.0.0'
+            if interface.version == 4:
+                hostmask_string = '0.0.0.0'
+            if interface.version == 6:
+                hostmask_string = '::'
 
         hostmask_ipobj = ipaddress.ip_address(hostmask_string)
 
@@ -577,13 +645,23 @@ def parse(
         try:
             netmask_string = str(interface.netmask)
         except AttributeError:
-            netmask_string = '255.255.255.255'
+            if interface.version == 4:
+                netmask_string = '255.255.255.255'
+            if interface.version == 6:
+                netmask_string = 'ffff:ffff:ffff:ffff:ffff:ffff:ffff:ffff'
 
         netmask_ipobj = ipaddress.ip_address(netmask_string)
 
         bare_ip_string = str(interface.ip)
         bare_ip = ipaddress.ip_address(bare_ip_string)
         ip_ptr = bare_ip.reverse_pointer
+        ip_compressed = bare_ip.compressed
+        ip_exploded = bare_ip.exploded
+
+        if interface.version == 4:
+            ip_split = ip_exploded.split('.')
+        else:
+            ip_split = ip_exploded.split(':')
 
         # fix for ipv6-only attributes
         scope_id = None
@@ -632,8 +710,9 @@ def parse(
             'version': interface.version,
             'max_prefix_length': interface.max_prefixlen,
             'ip': bare_ip_string,
-            'ip_compressed': bare_ip.compressed,
-            'ip_exploded': bare_ip.exploded,
+            'ip_compressed': ip_compressed,
+            'ip_exploded': ip_exploded,
+            'ip_split': ip_split,
             'scope_id': scope_id,
             'ipv4_mapped': ipv4_mapped,
             'six_to_four': sixtofour,
