@@ -9,11 +9,6 @@ Usage (module):
     import jc
     result = jc.parse('passwd', passwd_file_output)
 
-    or
-
-    import jc.parsers.passwd
-    result = jc.parsers.passwd.parse(passwd_file_output)
-
 Schema:
 
     [
@@ -121,8 +116,9 @@ def _process(proc_data):
 
         List of Dictionaries. Structured data to conform to the schema.
     """
+    int_list = {'uid', 'gid'}
+
     for entry in proc_data:
-        int_list = ['uid', 'gid']
         for key in entry:
             if key in int_list:
                 entry[key] = jc.utils.convert_to_int(entry[key])
