@@ -100,7 +100,7 @@ from jc.exceptions import ParseError
 
 class info():
     """Provides parser metadata (version, author, etc.)"""
-    version = '1.1'
+    version = '1.2'
     description = '`vmstat` command streaming parser'
     author = 'Kelly Brazil'
     author_email = 'kellyjonbrazil@gmail.com'
@@ -177,7 +177,7 @@ def parse(data, raw=False, quiet=False, ignore_exceptions=False):
             output_line = {}
 
             # skip blank lines
-            if line.strip() == '':
+            if not line.strip():
                 continue
 
             # detect output type
